#!/usr/bin/env python
# -*- coding: UTF-8 -*-
"""
@Project ：automation_nep
@File ：test.py
@Author ：RongYi
@Date ：2025/5/1 1:13
@E-mail ：2071914258@qq.com
"""
import os
root = r"D:/Papers/MyTools/automation_nep/abacus-dataset/0-99/1/STRU"
print('/'.join(root.split("/")[:-1])+"/time.json")
